<?php

/*
  Plugin Name: Envs Switcher
  Plugin URI: http://web-startup.fr/
  Description: Envs Switcher un plugin slwsu - modèle de base.
  Version: 1.3.0
  Author: Steeve Lefebvre
  Author URI: web-startup.fr/
  License: GPLv2 or later
  License URI: http://www.gnu.org/licenses/gpl-2.0.html
  Text Domain: ensw
  Contributors: webstartup, Benoti, citoyensdebout
  ------------------------------------------------------------------------------
  Note pour les anglophones : quand un code commenté en anglais me plait
  et qu'aucune traduction n'est disponible, je dois me démerder.
  Merci de bien vouloir me rendre la pareille :-þ
 */

defined('ABSPATH') or exit();

/**
 * GRP support
 */
if (!is_admin()):
    $ENVS_SWITCHER_PLUGIN = false;
else:
    if ('true' === get_option('slwsu_is_active_grouper', 'false')):
        if (!class_exists('slwsu_grouper_init')):
            require_once WP_PLUGIN_DIR . '/grouper/init.php';
        endif;
        $ENVS_SWITCHER_PLUGIN = new slwsu_grouper_init(get_option('slwsu_envs_switcher_grouper'), '4.4', '5.5');
    endif;
endif;

/**
 * Entrée du plugin
 */
class slwsu_envs_switcher {

    public function __construct() {

        // Hook
        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));
        add_action('plugins_loaded', array($this, 'text_domain'));
        add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'setting_links'));

        // Grouper 
        global $ENVS_SWITCHER_PLUGIN;
        if (is_object($ENVS_SWITCHER_PLUGIN)):
            if (false === $ENVS_SWITCHER_PLUGIN->wp_status or false === $ENVS_SWITCHER_PLUGIN->php_status):
                add_action('admin_init', array($this, 'deactivate_auto'));
            endif;
        endif;

        // Plugin
        $this->plugin();
    }

    /**
     * Plugin
     */
    private function plugin() {

        if (false !== get_option('bfsl_envs-switcher_production')):
            slwsu_envs_switcher::bfsl_maj();
        endif;

        include_once plugin_dir_path(__FILE__) . 'plugin/init.php';
        new slwsu_envs_switcher_plugin_init();
    }

    /**
     * 
     */
    public static function bfsl_maj() {
        include_once plugin_dir_path(__FILE__) . 'plugin/options.php';
        $options = slwsu_envs_switcher_options::options();
        foreach ($options as $k => $v):
            $option = get_option('bfsl_envs-switcher_' . $k);
            delete_option('bfsl_envs-switcher_' . $k);
            add_option('slwsu_envs_switcher_' . $k, $option);
        endforeach;
        delete_transient('bfsl_envs-switcher_options');
    }

    /**
     * Languages
     */
    public static function text_domain() {
        load_plugin_textdomain('ensw', false, dirname(plugin_basename(__FILE__)) . '/languages');
    }

    /**
     * Liens
     */
    public function setting_links($aLinks) {
        $links[] = '<a href="https://web-startup.fr/envs-switcher/">' . __('Page', 'ensw') . '</a>';
        $links[] = '<a href="' . admin_url('admin.php?page=envs-switcher') . '">' . __('Settings', 'ensw') . '</a>';
        return array_merge($links, $aLinks);
    }

    /**
     * Activation
     */
    public static function activate() {
        if (false !== get_option('bfsl_envs-switcher_production')):
            slwsu_envs_switcher::bfsl_maj();
        else:
            $option = slwsu_envs_switcher::options();
            foreach ($option as $k => $v):
                add_option($k, $v);
            endforeach;
            unset($k, $v);
        endif;
    }

    /**
     * Désactivation
     */
    public static function deactivate() {
        if ('true' === get_option('slwsu_envs_switcher_delete_options', 'false')):
            $option = slwsu_envs_switcher::options();
            foreach ($option as $k => $v):
                delete_option($k);
            endforeach;
            unset($k, $v);
        endif;
    }

    /**
     * Options
     */
    public static function options() {
        include_once plugin_dir_path(__FILE__) . 'plugin/options.php';
        return slwsu_envs_switcher_options::get_options();
    }

    /**
     * Désactivation automatique
     */
    public static function deactivate_auto() {
        // On désactive le plugin
        deactivate_plugins(plugin_basename(__FILE__));
    }

}

/**
 * 
 */
new slwsu_envs_switcher();
