<?php

defined('ABSPATH') or exit();

$envs = [
    'developpement' => get_option('slwsu_envs_switcher_developpement'),
    'test' => get_option('slwsu_envs_switcher_test'),
    'demonstration' => get_option('slwsu_envs_switcher_demonstration'),
    'production' => get_option('slwsu_envs_switcher_production'),
];


// La constante ENVIRONNEMENTS doit être un tableau sérialisé 'environment' => 'url'
defined('ENVS') or define('ENVS', serialize($envs));

// WP_ENV doit être défini comme l'environnement courent.
defined('WP_ENVS') or define('WP_ENVS', get_option('slwsu_envs_switcher_environement'));

// On garde le nom du dossier du site dans lacalhost
defined('LOCAL_DIR_NAME') or define('LOCAL_DIR_NAME', get_option('slwsu_envs_switcher_localhost'));

/**
 * 
 */
class bfsl_switcher {

    public function __construct() {
        if ('' !== get_option('slwsu_envs_switcher_production', '')):
            add_action('admin_bar_menu', [$this, 'admin_bar_stage_switcher']);
            add_action('wp_before_admin_bar_render', [$this, 'admin_css']);
        endif;
    }

    public function admin_bar_stage_switcher($oAdminBar) {
        if (!defined('ENVS') && !defined('WP_ENVS') && !is_admin()) {
            return;
        }

        $stages = unserialize(ENVS);
        $current_stage = WP_ENVS;

        foreach ($stages as $stage => $url) {
            if ($stage === $current_stage) {
                continue;
            }

            $oAdminBar->add_menu([
                'id' => 'environment',
                'parent' => 'top-secondary',
                'title' => ucwords($current_stage),
                'href' => '#'
            ]);

            if ('' !== $url):

                if (preg_match('#localhost#', $url)):
                    $url .= LOCAL_DIR_NAME . $_SERVER['REQUEST_URI'];
                else:
                    $_REQUEST_URI = str_replace('/' . LOCAL_DIR_NAME, '', $_SERVER['REQUEST_URI']);
                    $url .= $_REQUEST_URI;
                endif;

                // $url = preg_replace('/&?return=[^&]*/', '', $url);
                $url = preg_replace('/&[^&]*/', '', $url);

                $oAdminBar->add_menu([
                    'id' => "stage_$stage",
                    'parent' => 'environment',
                    'title' => ucwords($stage),
                    'href' => $url,
                    'meta' => array('target' => '_blank')
                ]);
            endif;
        }
    }

    public function admin_css() {
        ?>
        <style>
            #wp-admin-bar-environment > a:before {
                content: "\f541";
            }
        </style>
        <?php

    }

}

// Initialisation
new bfsl_switcher;
